@@ -7,23 +7,23 @@
 #ifndef KIRIGAMIPLASMAFACTORY_H
 #define KIRIGAMIPLASMAFACTORY_H
 
-#include <Kirigami/KirigamiPluginFactory>
+#include <Kirigami/Platform/PlatformPluginFactory>
 #include <QObject>
 
-class KirigamiPlasmaFactory : public Kirigami::KirigamiPluginFactoryV2
+class KirigamiPlasmaFactory : public Kirigami::Platform::PlatformPluginFactory
 {
     Q_OBJECT
 
-    Q_PLUGIN_METADATA(IID "org.kde.kirigami.KirigamiPluginFactory" FILE "kirigamiplasmaintegration.json")
+    Q_PLUGIN_METADATA(IID PlatformPluginFactory_iid FILE "kirigamiplasmaintegration.json")
 
-    Q_INTERFACES(Kirigami::KirigamiPluginFactory)
+    Q_INTERFACES(Kirigami::Platform::PlatformPluginFactory)
 
 public:
     explicit KirigamiPlasmaFactory(QObject *parent = nullptr);
     ~KirigamiPlasmaFactory() override;
 
-    Kirigami::PlatformTheme *createPlatformTheme(QObject *parent) override;
-    Kirigami::Units *createUnits(QObject *parent) override;
+    Kirigami::Platform::PlatformTheme *createPlatformTheme(QObject *parent) override;
+    Kirigami::Platform::Units *createUnits(QObject *parent) override;
 };
 
 #endif // KIRIGAMIPLASMAFACTORY_H
